#!/bin/sh
cd /var/www/html
if [ ! -f wp-config-sample.php ]; then
  # Check if config sample file is available and if not we need to download and configure WordPress
  wp core download --allow-root
fi

if [ ! -f wp-config.php ]; then
  # If there is no actual config generate one
  until wp core config --dbname=$WORDPRESS_DB --dbhost='mysql' --dbuser=$WORDPRESS_DB_USER --dbpass=$WORDPRESS_DB_PASSWORD --allow-root
  # Keep trying to create the config and test the details until it succeeds
  do
    echo 'Waiting for database connection....'
    sleep 3
  done

  if ! $(wp core is-installed --allow-root); then
    # Check for WordPress tables and if there isn't any install Wordpress
    # with the config details and activate the theme
    wp db create --allow-root
    echo 'Checking for existing package...'
    if [ -f wp-content/themes/theme/package.tar.gz ]; then
      echo 'Package found. Extracting...'
      mv wp-content/themes/theme/package.tar.gz .
      tar -xf package.tar.gz
      rm -rif wp-content/plugins
      mv build/plugins build/uploads wp-content
      wp db import build/dump.sql --allow-root
      echo 'Cleaning up...'
      rm -rif package.tar.gz build
    else
      echo 'Installing fresh environment...'
      wp core install --url=$WORDPRESS_URL --title=$WORDPRESS_TITLE --admin_user=$WORDPRESS_ADMIN_USER --admin_password=$WORDPRESS_ADMIN_PASS --admin_email=$WORDPRESS_ADMIN_EMAIL --allow-root
    fi
  fi
fi

until $(wp core is-installed --allow-root);
  # Keep checking if database is alive by checking for an installed WordPress
  do
    echo 'Waiting for database connection....'
    sleep 3
  done

echo 'Setting WordPress Permissions...'
find /var/www/html/ -type d -exec chmod 755 {} \;
find /var/www/html -type f -exec chmod 644 {} \;
chown -R www-data:www-data /var/www/html
echo 'Checking for parent theme...'
PARENT=$(awk '/Template/{print $NF}' wp-content/themes/theme/style.css) # Read CSS file for parent template
if [ ! -z "$PARENT" ]; then
  echo "Installing parent: $PARENT..."
  if [ -z "$PARENT_VERSION" ]; then
    wp theme install $PARENT --allow-root
  else
    wp theme install $PARENT --version=$PARENT_VERSION --allow-root
  fi
fi
echo 'Activating theme...'
wp theme activate theme --allow-root
service apache2 start
cd /var/www/html/wp-content/themes/theme && npm install
gulp
